@@ -49,12 +49,21 @@ class ClientBase(object):
     def get_client(self):
         return self.client
 
+    def get_name(self):
+        return self.jubatus_client.name
+
+    def set_name(self, name):
+        self.jubatus_client.name = name
+
     def save(self, id):
         return self.jubatus_client.call("save", [id], TBool(), [TString()])
 
     def load(self, id):
       return self.jubatus_client.call("load", [id], TBool(), [TString()])
 
+    def do_mix(self):
+        return self.jubatus_client.call("do_mix", [], TBool(), [])
+
     def get_config(self):
         return self.jubatus_client.call("get_config", [], TString(), [])
 
